task spladder_merge {
    String sample_id
    File bam
    File pickle
    File reference_gtf_file
    

    String docker
    String cluster
    String disk_size

    
    command <<<
        set -o pipefail
        set -e

        mkdir -p ${sample_id}/spladder_out/spladder
        
        ln -s ${bam}/*.bam ./                  
        ls ./ | grep bam$ > alignment.txt
        ln -s ${bam}/*.bai ./           
        ls ./ | grep bai$ > alignment_bai.txt
        ln -s ${pickle}/*.pickle ${sample_id}/spladder_out/spladder/
        ls ${sample_id}/spladder_out/spladder/ >> pickle.txt
		
        nt=$(nproc)
          
        spladder build -o ${sample_id}/spladder_out \
          --annotation ${reference_gtf_file} \
          --bams alignment.txt \
          --confidence 2 \
          --merge-strat merge_graphs \
          --readlen 150 \
          --parallel $nt \
          --event-types exon_skip
          
        find . -depth > fileList.txt
    >>>

    runtime {
        docker: docker
        cluster: cluster
        systemDisk: "cloud_ssd 500"
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
        timeout: 129600
    }

    output {
        File fileList = "fileList.txt"
        File alignment = "alignment.txt"
        File alignment_bai = "alignment_bai.txt"
        File pickle_txt = "pickle.txt"
        Array[File] AS_gff = glob("${sample_id}/spladder_out/*.gff3")
        Array[File] AS_gz = glob("${sample_id}/spladder_out/*.gz")
        Array[File] spladder_out = glob("${sample_id}/spladder_out/*")
        Array[File] spladder = glob("${sample_id}/spladder_out/spladder/*")
    }
}